==> odil_0.10.0.orig.tar.gz: odil-0.10.0/src/odil/registry_0068.h <==
/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ImplantSize(0x0068, 0x6210);
Tag const ImplantTemplateVersion(0x0068, 0x6221);
Tag const ReplacedImplantTemplateSequence(0x0068, 0x6222);
Tag const ImplantType(0x0068, 0x6223);
Tag const DerivationImplantTemplateSequence(0x0068, 0x6224);
Tag const OriginalImplantTemplateSequence(0x0068, 0x6225);
Tag const EffectiveDateTime(0x0068, 0x6226);
Tag const ImplantTargetAnatomySequence(0x0068, 0x6230);
Tag const InformationFromManufacturerSequence(0x0068, 0x6260);
Tag const NotificationFromManufacturerSequence(0x0068, 0x6265);
Tag const InformationIssueDateTime(0x0068, 0x6270);
Tag const InformationSummary(0x0068, 0x6280);
Tag const ImplantRegulatoryDisapprovalCodeSequence(0x0068, 0x62a0);
Tag const OverallTemplateSpatialTolerance(0x0068, 0x62a5);
Tag const HPGLDocumentSequence(0x0068, 0x62c0);
Tag const HPGLDocumentID(0x0068, 0x62d0);
Tag const HPGLDocumentLabel(0x0068, 0x62d5);
Tag const ViewOrientationCodeSequence(0x0068, 0x62e0);
Tag const ViewOrientationModifierCodeSequence(0x0068, 0x62f0);
Tag const HPGLDocumentScaling(0x0068, 0x62f2);
Tag const HPGLDocument(0x0068, 0x6300);
Tag const HPGLContourPenNumber(0x0068, 0x6310);
Tag const HPGLPenSequence(0x0068, 0x6320);
Tag const HPGLPenNumber(0x0068, 0x6330);
Tag const HPGLPenLabel(0x0068, 0x6340);
Tag const HPGLPenDescription(0x0068, 0x6345);
Tag const RecommendedRotationPoint(0x0068, 0x6346);
Tag const BoundingRectangle(0x0068, 0x6347);
Tag const ImplantTemplate3DModelSurfaceNumber(0x0068, 0x6350);
Tag const SurfaceModelDescriptionSequence(0x0068, 0x6360);
Tag const SurfaceModelLabel(0x0068, 0x6380);
Tag const SurfaceModelScalingFactor(0x0068, 0x6390);
Tag const MaterialsCodeSequence(0x0068, 0x63a0);
Tag const CoatingMaterialsCodeSequence(0x0068, 0x63a4);
Tag const ImplantTypeCodeSequence(0x0068, 0x63a8);
Tag const FixationMethodCodeSequence(0x0068, 0x63ac);
Tag const MatingFeatureSetsSequence(0x0068, 0x63b0);
Tag const MatingFeatureSetID(0x0068, 0x63c0);
Tag const MatingFeatureSetLabel(0x0068, 0x63d0);
Tag const MatingFeatureSequence(0x0068, 0x63e0);
Tag const MatingFeatureID(0x0068, 0x63f0);
Tag const MatingFeatureDegreeOfFreedomSequence(0x0068, 0x6400);
Tag const DegreeOfFreedomID(0x0068, 0x6410);
Tag const DegreeOfFreedomType(0x0068, 0x6420);
Tag const TwoDMatingFeatureCoordinatesSequence(0x0068, 0x6430);
Tag const ReferencedHPGLDocumentID(0x0068, 0x6440);
Tag const TwoDMatingPoint(0x0068, 0x6450);
Tag const TwoDMatingAxes(0x0068, 0x6460);
Tag const TwoDDegreeOfFreedomSequence(0x0068, 0x6470);
Tag const ThreeDDegreeOfFreedomAxis(0x0068, 0x6490);
Tag const RangeOfFreedom(0x0068, 0x64a0);
Tag const ThreeDMatingPoint(0x0068, 0x64c0);
Tag const ThreeDMatingAxes(0x0068, 0x64d0);
Tag const TwoDDegreeOfFreedomAxis(0x0068, 0x64f0);
Tag const PlanningLandmarkPointSequence(0x0068, 0x6500);
Tag const PlanningLandmarkLineSequence(0x0068, 0x6510);
Tag const PlanningLandmarkPlaneSequence(0x0068, 0x6520);
Tag const PlanningLandmarkID(0x0068, 0x6530);
Tag const PlanningLandmarkDescription(0x0068, 0x6540);
Tag const PlanningLandmarkIdentificationCodeSequence(0x0068, 0x6545);
Tag const TwoDPointCoordinatesSequence(0x0068, 0x6550);
Tag const TwoDPointCoordinates(0x0068, 0x6560);
Tag const ThreeDPointCoordinates(0x0068, 0x6590);
Tag const TwoDLineCoordinatesSequence(0x0068, 0x65a0);
Tag const TwoDLineCoordinates(0x0068, 0x65b0);
Tag const ThreeDLineCoordinates(0x0068, 0x65d0);
Tag const TwoDPlaneCoordinatesSequence(0x0068, 0x65e0);
Tag const TwoDPlaneIntersection(0x0068, 0x65f0);
Tag const ThreeDPlaneOrigin(0x0068, 0x6610);
Tag const ThreeDPlaneNormal(0x0068, 0x6620);
Tag const ModelModification(0x0068, 0x7001);
Tag const ModelMirroring(0x0068, 0x7002);
Tag const ModelUsageCodeSequence(0x0068, 0x7003);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068

==> odil_0.12.1.orig.tar.gz: odil-0.12.1/src/odil/registry_0068.h <==
/*************************************************************************
 * odil - Copyright (C) Universite de Strasbourg
 * Distributed under the terms of the CeCILL-B license, as published by
 * the CEA-CNRS-INRIA. Refer to the LICENSE file or to
 * http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
 * for details.
 ************************************************************************/

#ifndef _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068
#define _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068

#include <map>
#include <string>

#include "odil/odil.h"
#include "odil/Tag.h"

namespace odil
{

namespace registry
{
Tag const ImplantSize(0x0068, 0x6210);
Tag const ImplantTemplateVersion(0x0068, 0x6221);
Tag const ReplacedImplantTemplateSequence(0x0068, 0x6222);
Tag const ImplantType(0x0068, 0x6223);
Tag const DerivationImplantTemplateSequence(0x0068, 0x6224);
Tag const OriginalImplantTemplateSequence(0x0068, 0x6225);
Tag const EffectiveDateTime(0x0068, 0x6226);
Tag const ImplantTargetAnatomySequence(0x0068, 0x6230);
Tag const InformationFromManufacturerSequence(0x0068, 0x6260);
Tag const NotificationFromManufacturerSequence(0x0068, 0x6265);
Tag const InformationIssueDateTime(0x0068, 0x6270);
Tag const InformationSummary(0x0068, 0x6280);
Tag const ImplantRegulatoryDisapprovalCodeSequence(0x0068, 0x62a0);
Tag const OverallTemplateSpatialTolerance(0x0068, 0x62a5);
Tag const HPGLDocumentSequence(0x0068, 0x62c0);
Tag const HPGLDocumentID(0x0068, 0x62d0);
Tag const HPGLDocumentLabel(0x0068, 0x62d5);
Tag const ViewOrientationCodeSequence(0x0068, 0x62e0);
Tag const ViewOrientationModifierCodeSequence(0x0068, 0x62f0);
Tag const HPGLDocumentScaling(0x0068, 0x62f2);
Tag const HPGLDocument(0x0068, 0x6300);
Tag const HPGLContourPenNumber(0x0068, 0x6310);
Tag const HPGLPenSequence(0x0068, 0x6320);
Tag const HPGLPenNumber(0x0068, 0x6330);
Tag const HPGLPenLabel(0x0068, 0x6340);
Tag const HPGLPenDescription(0x0068, 0x6345);
Tag const RecommendedRotationPoint(0x0068, 0x6346);
Tag const BoundingRectangle(0x0068, 0x6347);
Tag const ImplantTemplate3DModelSurfaceNumber(0x0068, 0x6350);
Tag const SurfaceModelDescriptionSequence(0x0068, 0x6360);
Tag const SurfaceModelLabel(0x0068, 0x6380);
Tag const SurfaceModelScalingFactor(0x0068, 0x6390);
Tag const MaterialsCodeSequence(0x0068, 0x63a0);
Tag const CoatingMaterialsCodeSequence(0x0068, 0x63a4);
Tag const ImplantTypeCodeSequence(0x0068, 0x63a8);
Tag const FixationMethodCodeSequence(0x0068, 0x63ac);
Tag const MatingFeatureSetsSequence(0x0068, 0x63b0);
Tag const MatingFeatureSetID(0x0068, 0x63c0);
Tag const MatingFeatureSetLabel(0x0068, 0x63d0);
Tag const MatingFeatureSequence(0x0068, 0x63e0);
Tag const MatingFeatureID(0x0068, 0x63f0);
Tag const MatingFeatureDegreeOfFreedomSequence(0x0068, 0x6400);
Tag const DegreeOfFreedomID(0x0068, 0x6410);
Tag const DegreeOfFreedomType(0x0068, 0x6420);
Tag const TwoDMatingFeatureCoordinatesSequence(0x0068, 0x6430);
Tag const ReferencedHPGLDocumentID(0x0068, 0x6440);
Tag const TwoDMatingPoint(0x0068, 0x6450);
Tag const TwoDMatingAxes(0x0068, 0x6460);
Tag const TwoDDegreeOfFreedomSequence(0x0068, 0x6470);
Tag const ThreeDDegreeOfFreedomAxis(0x0068, 0x6490);
Tag const RangeOfFreedom(0x0068, 0x64a0);
Tag const ThreeDMatingPoint(0x0068, 0x64c0);
Tag const ThreeDMatingAxes(0x0068, 0x64d0);
Tag const TwoDDegreeOfFreedomAxis(0x0068, 0x64f0);
Tag const PlanningLandmarkPointSequence(0x0068, 0x6500);
Tag const PlanningLandmarkLineSequence(0x0068, 0x6510);
Tag const PlanningLandmarkPlaneSequence(0x0068, 0x6520);
Tag const PlanningLandmarkID(0x0068, 0x6530);
Tag const PlanningLandmarkDescription(0x0068, 0x6540);
Tag const PlanningLandmarkIdentificationCodeSequence(0x0068, 0x6545);
Tag const TwoDPointCoordinatesSequence(0x0068, 0x6550);
Tag const TwoDPointCoordinates(0x0068, 0x6560);
Tag const ThreeDPointCoordinates(0x0068, 0x6590);
Tag const TwoDLineCoordinatesSequence(0x0068, 0x65a0);
Tag const TwoDLineCoordinates(0x0068, 0x65b0);
Tag const ThreeDLineCoordinates(0x0068, 0x65d0);
Tag const TwoDPlaneCoordinatesSequence(0x0068, 0x65e0);
Tag const TwoDPlaneIntersection(0x0068, 0x65f0);
Tag const ThreeDPlaneOrigin(0x0068, 0x6610);
Tag const ThreeDPlaneNormal(0x0068, 0x6620);
Tag const ModelModification(0x0068, 0x7001);
Tag const ModelMirroring(0x0068, 0x7002);
Tag const ModelUsageCodeSequence(0x0068, 0x7003);
Tag const ModelGroupUID(0x0068, 0x7004);
Tag const RelativeURIReferenceWithinEncapsulatedDocument(0x0068, 0x7005);

}

}

#endif // _afc7b2d7_0869_4fea_9a9b_7fe6228baca9_0068
